==> jbossws-spi-1.0.5.GA-sources.jar: org/jboss/wsf/spi/metadata/j2ee/serviceref/UnifiedHandlerChainsMetaData.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wsf.spi.metadata.j2ee.serviceref;

import java.util.ArrayList;
import java.util.List;

import org.jboss.wsf.spi.metadata.j2ee.serviceref.UnifiedHandlerMetaData.HandlerType;
import org.jboss.wsf.spi.serviceref.ServiceRefElement;

/** The unified metdata data for a handler chains element
 * 
 * @author Thomas.Diesler@jboss.org
 */
public class UnifiedHandlerChainsMetaData extends ServiceRefElement
{
   private HandlerType handlerType;
   private List<UnifiedHandlerChainMetaData> handlerChains = new ArrayList<UnifiedHandlerChainMetaData>();

   public UnifiedHandlerChainsMetaData(HandlerType endpoint)
   {
      this.handlerType = handlerType;
   }

   public UnifiedHandlerChainsMetaData()
   {
   }

   public List<UnifiedHandlerChainMetaData> getHandlerChains()
   {
      return handlerChains;
   }

   public void addHandlerChain(UnifiedHandlerChainMetaData handlerChain)
   {
      handlerChains.add(handlerChain);
   }
}

==> jbossws-spi-1.2.1.GA-sources.jar: org/jboss/wsf/spi/metadata/j2ee/serviceref/UnifiedHandlerChainsMetaData.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2006, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wsf.spi.metadata.j2ee.serviceref;

import java.util.ArrayList;
import java.util.List;

import org.jboss.wsf.spi.metadata.j2ee.serviceref.UnifiedHandlerMetaData.HandlerType;
import org.jboss.wsf.spi.serviceref.ServiceRefElement;

/** The unified metdata data for a handler chains element
 * 
 * @author Thomas.Diesler@jboss.org
 */
public class UnifiedHandlerChainsMetaData extends ServiceRefElement
{
   private HandlerType handlerType;
   private List<UnifiedHandlerChainMetaData> handlerChains = new ArrayList<UnifiedHandlerChainMetaData>();

   public UnifiedHandlerChainsMetaData(HandlerType handlerType)
   {
      this.handlerType = handlerType;
   }

   public UnifiedHandlerChainsMetaData()
   {
   }

   public List<UnifiedHandlerChainMetaData> getHandlerChains()
   {
      return handlerChains;
   }

   public void addHandlerChain(UnifiedHandlerChainMetaData handlerChain)
   {
      handlerChains.add(handlerChain);
   }
}
